# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt
from public_api_server_connector.models.content import Content
from public_api_server_connector.models.content_block_type_str_enum import ContentBlockTypeStrEnum

class CourseContentBlock(BaseModel):
    """
    CourseContentBlock
    """
    block_type: ContentBlockTypeStrEnum = Field(...)
    order: StrictInt = Field(...)
    is_expanded: StrictBool = Field(...)
    content: Optional[Content] = None
    id: StrictInt = Field(...)
    course_id: StrictInt = Field(...)
    created_at: StrictInt = Field(default=..., description="Unix timestamp in milliseconds when the content block was created")
    __properties = ["block_type", "order", "is_expanded", "content", "id", "course_id", "created_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CourseContentBlock:
        """Create an instance of CourseContentBlock from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of content
        if self.content:
            _dict['content'] = self.content.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CourseContentBlock:
        """Create an instance of CourseContentBlock from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CourseContentBlock.parse_obj(obj)

        _obj = CourseContentBlock.parse_obj({
            "block_type": obj.get("block_type"),
            "order": obj.get("order"),
            "is_expanded": obj.get("is_expanded"),
            "content": Content.from_dict(obj.get("content")) if obj.get("content") is not None else None,
            "id": obj.get("id"),
            "course_id": obj.get("course_id"),
            "created_at": obj.get("created_at")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class FileUploadResult(BaseModel):
    """
    FileUploadResult
    """
    id: StrictInt = Field(default=..., description="Mediastorage database ID, can be used to retrieve the file metadata, delete the file, etc.")
    file_id: StrictStr = Field(default=..., description="Unique file hash identifier that can be used to retrieve the file later")
    file_url: StrictStr = Field(default=..., description="Direct URL to access the file")
    embed_html: Optional[StrictStr] = Field(default=None, description="HTML snippet that can be used to embed the file in a web page. Only for images.")
    __properties = ["id", "file_id", "file_url", "embed_html"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FileUploadResult:
        """Create an instance of FileUploadResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FileUploadResult:
        """Create an instance of FileUploadResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FileUploadResult.parse_obj(obj)

        _obj = FileUploadResult.parse_obj({
            "id": obj.get("id"),
            "file_id": obj.get("file_id"),
            "file_url": obj.get("file_url"),
            "embed_html": obj.get("embed_html")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from public_api_server_connector.models.course_submodule import CourseSubmodule
from public_api_server_connector.models.module_lesson import ModuleLesson

class CourseModule(BaseModel):
    """
    CourseModule
    """
    mandatory: Optional[StrictBool] = False
    is_published: Optional[StrictBool] = False
    is_active: Optional[StrictBool] = False
    title: StrictStr = Field(...)
    public_description: Optional[StrictStr] = None
    short_description: Optional[StrictStr] = None
    image_id: Optional[StrictStr] = None
    available_at: Optional[StrictInt] = Field(default=None, description="Timestamp in unix milliseconds when the module becomes available")
    id: StrictInt = Field(...)
    course_id: StrictInt = Field(...)
    order: StrictInt = Field(...)
    submodules: conlist(CourseSubmodule) = Field(...)
    lessons: conlist(ModuleLesson) = Field(...)
    __properties = ["mandatory", "is_published", "is_active", "title", "public_description", "short_description", "image_id", "available_at", "id", "course_id", "order", "submodules", "lessons"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CourseModule:
        """Create an instance of CourseModule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in submodules (list)
        _items = []
        if self.submodules:
            for _item in self.submodules:
                if _item:
                    _items.append(_item.to_dict())
            _dict['submodules'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in lessons (list)
        _items = []
        if self.lessons:
            for _item in self.lessons:
                if _item:
                    _items.append(_item.to_dict())
            _dict['lessons'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CourseModule:
        """Create an instance of CourseModule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CourseModule.parse_obj(obj)

        _obj = CourseModule.parse_obj({
            "mandatory": obj.get("mandatory") if obj.get("mandatory") is not None else False,
            "is_published": obj.get("is_published") if obj.get("is_published") is not None else False,
            "is_active": obj.get("is_active") if obj.get("is_active") is not None else False,
            "title": obj.get("title"),
            "public_description": obj.get("public_description"),
            "short_description": obj.get("short_description"),
            "image_id": obj.get("image_id"),
            "available_at": obj.get("available_at"),
            "id": obj.get("id"),
            "course_id": obj.get("course_id"),
            "order": obj.get("order"),
            "submodules": [CourseSubmodule.from_dict(_item) for _item in obj.get("submodules")] if obj.get("submodules") is not None else None,
            "lessons": [ModuleLesson.from_dict(_item) for _item in obj.get("lessons")] if obj.get("lessons") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing import overload, Optional, Union, Awaitable

from typing_extensions import Annotated
from pydantic import Field, StrictBytes, StrictInt, StrictStr

from typing import Optional, Union

from public_api_server_connector.models.file_update import FileUpdate
from public_api_server_connector.models.folder_create import FolderCreate
from public_api_server_connector.models.folder_update import FolderUpdate
from public_api_server_connector.models.response_wrapper_bool import ResponseWrapperBool
from public_api_server_connector.models.response_wrapper_file import ResponseWrapperFile
from public_api_server_connector.models.response_wrapper_file_upload_result import ResponseWrapperFileUploadResult
from public_api_server_connector.models.response_wrapper_folder import ResponseWrapperFolder
from public_api_server_connector.models.response_wrapper_int import ResponseWrapperInt
from public_api_server_connector.models.response_wrapper_list_file import ResponseWrapperListFile
from public_api_server_connector.models.response_wrapper_list_folder import ResponseWrapperListFolder

from public_api_server_connector.api_client import ApiClient
from public_api_server_connector.api_response import ApiResponse
from public_api_server_connector.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MediastorageApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    async def api_key_auth_create_folder(self, folder_create : FolderCreate, **kwargs) -> ResponseWrapperInt:  # noqa: E501
        """Create Folder  # noqa: E501

        Create folder in mediastorage  # noqa: E501

        :param folder_create: (required)
        :type folder_create: FolderCreate
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperInt
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_create_folder_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_create_folder_with_http_info(folder_create, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_create_folder_with_http_info(self, folder_create : FolderCreate, **kwargs) -> ApiResponse:  # noqa: E501
        """Create Folder  # noqa: E501

        Create folder in mediastorage  # noqa: E501

        :param folder_create: (required)
        :type folder_create: FolderCreate
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperInt, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'folder_create'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_create_folder" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['folder_create'] is not None:
            _body_params = _params['folder_create']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperInt",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_delete_file(self, id_ : StrictInt, **kwargs) -> ResponseWrapperBool:  # noqa: E501
        """Delete File  # noqa: E501

        Get file from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperBool
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_delete_file_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_delete_file_with_http_info(id_, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_delete_file_with_http_info(self, id_ : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Delete File  # noqa: E501

        Get file from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperBool, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id_'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_delete_file" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id_'] is not None:
            _path_params['id_'] = _params['id_']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperBool",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files/{id_}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_delete_folder(self, id_ : StrictInt, **kwargs) -> ResponseWrapperBool:  # noqa: E501
        """Delete Folder  # noqa: E501

        Delete folder from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperBool
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_delete_folder_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_delete_folder_with_http_info(id_, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_delete_folder_with_http_info(self, id_ : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Delete Folder  # noqa: E501

        Delete folder from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperBool, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id_'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_delete_folder" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id_'] is not None:
            _path_params['id_'] = _params['id_']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperBool",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders/{id_}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_all_files_count(self, **kwargs) -> ResponseWrapperInt:  # noqa: E501
        """Get All Files Count  # noqa: E501

        Get file count in mediastorage, nesting is ignored  # noqa: E501

        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperInt
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_all_files_count_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_all_files_count_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_all_files_count_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """Get All Files Count  # noqa: E501

        Get file count in mediastorage, nesting is ignored  # noqa: E501

        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperInt, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_all_files_count" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperInt",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files/all/count', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_all_folders(self, limit : Annotated[Optional[StrictInt], Field(description="Number of folders to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, **kwargs) -> ResponseWrapperListFolder:  # noqa: E501
        """Get All Folders  # noqa: E501

        List folders in mediastorage, nesting is ignored  # noqa: E501

        :param limit: Number of folders to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperListFolder
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_all_folders_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_all_folders_with_http_info(limit, offset, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_all_folders_with_http_info(self, limit : Annotated[Optional[StrictInt], Field(description="Number of folders to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get All Folders  # noqa: E501

        List folders in mediastorage, nesting is ignored  # noqa: E501

        :param limit: Number of folders to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperListFolder, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_all_folders" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperListFolder",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders/all', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_all_folders_count(self, **kwargs) -> ResponseWrapperInt:  # noqa: E501
        """Get All Folders Count  # noqa: E501

        Get folder count in mediastorage, nesting is ignored  # noqa: E501

        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperInt
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_all_folders_count_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_all_folders_count_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_all_folders_count_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """Get All Folders Count  # noqa: E501

        Get folder count in mediastorage, nesting is ignored  # noqa: E501

        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperInt, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_all_folders_count" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperInt",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders/all/count', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_file(self, id_ : StrictInt, **kwargs) -> ResponseWrapperFile:  # noqa: E501
        """Get File  # noqa: E501

        Get file from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperFile
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_file_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_file_with_http_info(id_, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_file_with_http_info(self, id_ : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Get File  # noqa: E501

        Get file from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperFile, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id_'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_file" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id_'] is not None:
            _path_params['id_'] = _params['id_']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperFile",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files/{id_}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_files(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list files from")] = None, limit : Annotated[Optional[StrictInt], Field(description="Number of files to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, filename : Annotated[Optional[StrictStr], Field(description="Filter files by filename (partial match)")] = None, **kwargs) -> ResponseWrapperListFile:  # noqa: E501
        """Get Files  # noqa: E501

        List files in mediastorage. Files are listed by their parent folder. If no parent folder is provided, lists root files.  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list files from
        :type parent_folder_id: int
        :param limit: Number of files to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param filename: Filter files by filename (partial match)
        :type filename: str
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperListFile
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_files_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_files_with_http_info(parent_folder_id, limit, offset, filename, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_files_with_http_info(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list files from")] = None, limit : Annotated[Optional[StrictInt], Field(description="Number of files to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, filename : Annotated[Optional[StrictStr], Field(description="Filter files by filename (partial match)")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Files  # noqa: E501

        List files in mediastorage. Files are listed by their parent folder. If no parent folder is provided, lists root files.  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list files from
        :type parent_folder_id: int
        :param limit: Number of files to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param filename: Filter files by filename (partial match)
        :type filename: str
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperListFile, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'parent_folder_id',
            'limit',
            'offset',
            'filename'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_files" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('parent_folder_id') is not None:  # noqa: E501
            _query_params.append(('parent_folder_id', _params['parent_folder_id']))

        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('filename') is not None:  # noqa: E501
            _query_params.append(('filename', _params['filename']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperListFile",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_files_all(self, limit : Annotated[Optional[StrictInt], Field(description="Number of files to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, filename : Annotated[Optional[StrictStr], Field(description="Filter files by filename (partial match)")] = None, **kwargs) -> ResponseWrapperListFile:  # noqa: E501
        """Get Files All  # noqa: E501

        List files in mediastorage. Files are listed regardless of their parent folder.  # noqa: E501

        :param limit: Number of files to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param filename: Filter files by filename (partial match)
        :type filename: str
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperListFile
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_files_all_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_files_all_with_http_info(limit, offset, filename, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_files_all_with_http_info(self, limit : Annotated[Optional[StrictInt], Field(description="Number of files to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, filename : Annotated[Optional[StrictStr], Field(description="Filter files by filename (partial match)")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Files All  # noqa: E501

        List files in mediastorage. Files are listed regardless of their parent folder.  # noqa: E501

        :param limit: Number of files to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param filename: Filter files by filename (partial match)
        :type filename: str
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperListFile, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset',
            'filename'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_files_all" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('filename') is not None:  # noqa: E501
            _query_params.append(('filename', _params['filename']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperListFile",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files/all', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_files_count(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list files from. If not provided, counts files in the root folder.")] = None, **kwargs) -> ResponseWrapperInt:  # noqa: E501
        """Get Files Count  # noqa: E501

        Get file count in mediastorage, nesting is considered, if parent_folder_id is provided, counts only files in the root folder  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list files from. If not provided, counts files in the root folder.
        :type parent_folder_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperInt
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_files_count_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_files_count_with_http_info(parent_folder_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_files_count_with_http_info(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list files from. If not provided, counts files in the root folder.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Files Count  # noqa: E501

        Get file count in mediastorage, nesting is considered, if parent_folder_id is provided, counts only files in the root folder  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list files from. If not provided, counts files in the root folder.
        :type parent_folder_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperInt, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'parent_folder_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_files_count" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('parent_folder_id') is not None:  # noqa: E501
            _query_params.append(('parent_folder_id', _params['parent_folder_id']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperInt",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files/count', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_folder(self, id_ : StrictInt, **kwargs) -> ResponseWrapperFolder:  # noqa: E501
        """Get Folder  # noqa: E501

        Get folder from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperFolder
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_folder_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_folder_with_http_info(id_, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_folder_with_http_info(self, id_ : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Folder  # noqa: E501

        Get folder from mediastorage by ID  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperFolder, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id_'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_folder" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id_'] is not None:
            _path_params['id_'] = _params['id_']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperFolder",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders/{id_}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_folders(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list subfolders from. If not provided, lists root folders.")] = None, limit : Annotated[Optional[StrictInt], Field(description="Number of folders to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, **kwargs) -> ResponseWrapperListFolder:  # noqa: E501
        """Get Folders  # noqa: E501

        List folders in mediastorage  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list subfolders from. If not provided, lists root folders.
        :type parent_folder_id: int
        :param limit: Number of folders to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperListFolder
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_folders_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_folders_with_http_info(parent_folder_id, limit, offset, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_folders_with_http_info(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list subfolders from. If not provided, lists root folders.")] = None, limit : Annotated[Optional[StrictInt], Field(description="Number of folders to return")] = None, offset : Annotated[Optional[StrictInt], Field(description="Offset for pagination")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Folders  # noqa: E501

        List folders in mediastorage  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list subfolders from. If not provided, lists root folders.
        :type parent_folder_id: int
        :param limit: Number of folders to return
        :type limit: int
        :param offset: Offset for pagination
        :type offset: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperListFolder, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'parent_folder_id',
            'limit',
            'offset'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_folders" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('parent_folder_id') is not None:  # noqa: E501
            _query_params.append(('parent_folder_id', _params['parent_folder_id']))

        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperListFolder",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_get_folders_count(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list subfolders from. If not provided, lists root folders.")] = None, **kwargs) -> ResponseWrapperInt:  # noqa: E501
        """Get Folders Count  # noqa: E501

        Get folder count in mediastorage, nesting is considered, if parent_folder_id is provided, counts only subfolders of the root folder  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list subfolders from. If not provided, lists root folders.
        :type parent_folder_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperInt
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_get_folders_count_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_get_folders_count_with_http_info(parent_folder_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_get_folders_count_with_http_info(self, parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to list subfolders from. If not provided, lists root folders.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Folders Count  # noqa: E501

        Get folder count in mediastorage, nesting is considered, if parent_folder_id is provided, counts only subfolders of the root folder  # noqa: E501

        :param parent_folder_id: ID of the parent folder to list subfolders from. If not provided, lists root folders.
        :type parent_folder_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperInt, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'parent_folder_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_get_folders_count" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('parent_folder_id') is not None:  # noqa: E501
            _query_params.append(('parent_folder_id', _params['parent_folder_id']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperInt",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders/count', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_update_file(self, id_ : StrictInt, file_update : FileUpdate, **kwargs) -> ResponseWrapperBool:  # noqa: E501
        """Update File  # noqa: E501

        Update folder in mediastorage  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param file_update: (required)
        :type file_update: FileUpdate
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperBool
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_update_file_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_update_file_with_http_info(id_, file_update, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_update_file_with_http_info(self, id_ : StrictInt, file_update : FileUpdate, **kwargs) -> ApiResponse:  # noqa: E501
        """Update File  # noqa: E501

        Update folder in mediastorage  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param file_update: (required)
        :type file_update: FileUpdate
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperBool, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id_',
            'file_update'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_update_file" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id_'] is not None:
            _path_params['id_'] = _params['id_']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['file_update'] is not None:
            _body_params = _params['file_update']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperBool",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files/{id_}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_update_folder(self, id_ : StrictInt, folder_update : FolderUpdate, **kwargs) -> ResponseWrapperBool:  # noqa: E501
        """Update Folder  # noqa: E501

        Update folder in mediastorage  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param folder_update: (required)
        :type folder_update: FolderUpdate
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperBool
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_update_folder_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_update_folder_with_http_info(id_, folder_update, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_update_folder_with_http_info(self, id_ : StrictInt, folder_update : FolderUpdate, **kwargs) -> ApiResponse:  # noqa: E501
        """Update Folder  # noqa: E501

        Update folder in mediastorage  # noqa: E501

        :param id_: (required)
        :type id_: int
        :param folder_update: (required)
        :type folder_update: FolderUpdate
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperBool, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id_',
            'folder_update'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_update_folder" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id_'] is not None:
            _path_params['id_'] = _params['id_']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['folder_update'] is not None:
            _body_params = _params['folder_update']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperBool",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/folders/{id_}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def api_key_auth_upload_file(self, file : Union[StrictBytes, StrictStr], parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to upload the file to")] = None, **kwargs) -> ResponseWrapperFileUploadResult:  # noqa: E501
        """Upload File  # noqa: E501

        Upload file to mediastorage  # noqa: E501

        :param file: (required)
        :type file: bytearray
        :param parent_folder_id: ID of the parent folder to upload the file to
        :type parent_folder_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseWrapperFileUploadResult
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the api_key_auth_upload_file_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.api_key_auth_upload_file_with_http_info(file, parent_folder_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def api_key_auth_upload_file_with_http_info(self, file : Union[StrictBytes, StrictStr], parent_folder_id : Annotated[Optional[StrictInt], Field(description="ID of the parent folder to upload the file to")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Upload File  # noqa: E501

        Upload file to mediastorage  # noqa: E501

        :param file: (required)
        :type file: bytearray
        :param parent_folder_id: ID of the parent folder to upload the file to
        :type parent_folder_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseWrapperFileUploadResult, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'file',
            'parent_folder_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_key_auth_upload_file" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['file'] is not None:
            _files['file'] = _params['file']

        if _params['parent_folder_id'] is not None:
            _form_params.append(('parent_folder_id', _params['parent_folder_id']))

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['APIKeyHeader', 'HTTPBearer']  # noqa: E501

        _response_types_map = {
            '200': "ResponseWrapperFileUploadResult",
            '500': "ResponseWrapper",
            '400': "ResponseWrapper",
            '401': "ResponseWrapper",
            '403': "ResponseWrapper",
            '404': "ResponseWrapper",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/mediastorage/v1/files/upload', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from public_api_server_connector.models.category_method_options import CategoryMethodOptions

class Category(BaseModel):
    """
    Category
    """
    name: StrictStr = Field(...)
    create: Optional[CategoryMethodOptions] = None
    read: Optional[CategoryMethodOptions] = None
    update: Optional[CategoryMethodOptions] = None
    delete: Optional[CategoryMethodOptions] = None
    __properties = ["name", "create", "read", "update", "delete"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Category:
        """Create an instance of Category from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of create
        if self.create:
            _dict['create'] = self.create.to_dict()
        # override the default output from pydantic by calling `to_dict()` of read
        if self.read:
            _dict['read'] = self.read.to_dict()
        # override the default output from pydantic by calling `to_dict()` of update
        if self.update:
            _dict['update'] = self.update.to_dict()
        # override the default output from pydantic by calling `to_dict()` of delete
        if self.delete:
            _dict['delete'] = self.delete.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Category:
        """Create an instance of Category from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Category.parse_obj(obj)

        _obj = Category.parse_obj({
            "name": obj.get("name"),
            "create": CategoryMethodOptions.from_dict(obj.get("create")) if obj.get("create") is not None else None,
            "read": CategoryMethodOptions.from_dict(obj.get("read")) if obj.get("read") is not None else None,
            "update": CategoryMethodOptions.from_dict(obj.get("update")) if obj.get("update") is not None else None,
            "delete": CategoryMethodOptions.from_dict(obj.get("delete")) if obj.get("delete") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from public_api_server_connector.models.address import Address
from public_api_server_connector.models.api_key_create import ApiKeyCreate
from public_api_server_connector.models.api_key_create_response import ApiKeyCreateResponse
from public_api_server_connector.models.api_key_get import ApiKeyGet
from public_api_server_connector.models.api_key_patch import ApiKeyPatch
from public_api_server_connector.models.api_key_update import ApiKeyUpdate
from public_api_server_connector.models.api_log_get import ApiLogGet
from public_api_server_connector.models.attached_file import AttachedFile
from public_api_server_connector.models.attached_file_create import AttachedFileCreate
from public_api_server_connector.models.attached_file_create_or_update import AttachedFileCreateOrUpdate
from public_api_server_connector.models.attached_file_patch import AttachedFilePatch
from public_api_server_connector.models.attached_files_inner import AttachedFilesInner
from public_api_server_connector.models.button_position import ButtonPosition
from public_api_server_connector.models.button_size import ButtonSize
from public_api_server_connector.models.button_target import ButtonTarget
from public_api_server_connector.models.category import Category
from public_api_server_connector.models.category_method_options import CategoryMethodOptions
from public_api_server_connector.models.category_permissions import CategoryPermissions
from public_api_server_connector.models.content import Content
from public_api_server_connector.models.content_block import ContentBlock
from public_api_server_connector.models.content_block_create import ContentBlockCreate
from public_api_server_connector.models.content_block_patch import ContentBlockPatch
from public_api_server_connector.models.content_block_type_str_enum import ContentBlockTypeStrEnum
from public_api_server_connector.models.content_block_update import ContentBlockUpdate
from public_api_server_connector.models.content_blocks_inner import ContentBlocksInner
from public_api_server_connector.models.content_blocks_inner1 import ContentBlocksInner1
from public_api_server_connector.models.course import Course
from public_api_server_connector.models.course_access_type_str_enum import CourseAccessTypeStrEnum
from public_api_server_connector.models.course_content_block import CourseContentBlock
from public_api_server_connector.models.course_create import CourseCreate
from public_api_server_connector.models.course_module import CourseModule
from public_api_server_connector.models.course_module_create import CourseModuleCreate
from public_api_server_connector.models.course_module_patch import CourseModulePatch
from public_api_server_connector.models.course_module_simple import CourseModuleSimple
from public_api_server_connector.models.course_module_update import CourseModuleUpdate
from public_api_server_connector.models.course_module_view_type_str_enum import CourseModuleViewTypeStrEnum
from public_api_server_connector.models.course_patch import CoursePatch
from public_api_server_connector.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum
from public_api_server_connector.models.course_simple import CourseSimple
from public_api_server_connector.models.course_submodule import CourseSubmodule
from public_api_server_connector.models.course_submodule_create import CourseSubmoduleCreate
from public_api_server_connector.models.course_submodule_patch import CourseSubmodulePatch
from public_api_server_connector.models.course_submodule_update import CourseSubmoduleUpdate
from public_api_server_connector.models.course_update import CourseUpdate
from public_api_server_connector.models.file import File
from public_api_server_connector.models.file_update import FileUpdate
from public_api_server_connector.models.file_upload_result import FileUploadResult
from public_api_server_connector.models.folder import Folder
from public_api_server_connector.models.folder_create import FolderCreate
from public_api_server_connector.models.folder_update import FolderUpdate
from public_api_server_connector.models.http_validation_error import HTTPValidationError
from public_api_server_connector.models.http_method import HttpMethod
from public_api_server_connector.models.ipn_order_payment import IpnOrderPayment
from public_api_server_connector.models.ipn_order_payment_response import IpnOrderPaymentResponse
from public_api_server_connector.models.ipn_transaction import IpnTransaction
from public_api_server_connector.models.lesson_type_str_enum import LessonTypeStrEnum
from public_api_server_connector.models.location_inner import LocationInner
from public_api_server_connector.models.marketplace_buyer import MarketplaceBuyer
from public_api_server_connector.models.module_lesson import ModuleLesson
from public_api_server_connector.models.module_lesson_create import ModuleLessonCreate
from public_api_server_connector.models.module_lesson_patch import ModuleLessonPatch
from public_api_server_connector.models.module_lesson_patch_attached_files import ModuleLessonPatchAttachedFiles
from public_api_server_connector.models.module_lesson_patch_content import ModuleLessonPatchContent
from public_api_server_connector.models.module_lesson_simple import ModuleLessonSimple
from public_api_server_connector.models.module_lesson_update import ModuleLessonUpdate
from public_api_server_connector.models.portal_info import PortalInfo
from public_api_server_connector.models.portal_member_base import PortalMemberBase
from public_api_server_connector.models.response_wrapper import ResponseWrapper
from public_api_server_connector.models.response_wrapper_api_key_create_response import ResponseWrapperApiKeyCreateResponse
from public_api_server_connector.models.response_wrapper_api_key_get import ResponseWrapperApiKeyGet
from public_api_server_connector.models.response_wrapper_api_log_get import ResponseWrapperApiLogGet
from public_api_server_connector.models.response_wrapper_bool import ResponseWrapperBool
from public_api_server_connector.models.response_wrapper_course import ResponseWrapperCourse
from public_api_server_connector.models.response_wrapper_course_module import ResponseWrapperCourseModule
from public_api_server_connector.models.response_wrapper_course_module_simple import ResponseWrapperCourseModuleSimple
from public_api_server_connector.models.response_wrapper_course_simple import ResponseWrapperCourseSimple
from public_api_server_connector.models.response_wrapper_course_submodule import ResponseWrapperCourseSubmodule
from public_api_server_connector.models.response_wrapper_file import ResponseWrapperFile
from public_api_server_connector.models.response_wrapper_file_upload_result import ResponseWrapperFileUploadResult
from public_api_server_connector.models.response_wrapper_folder import ResponseWrapperFolder
from public_api_server_connector.models.response_wrapper_int import ResponseWrapperInt
from public_api_server_connector.models.response_wrapper_ipn_order_payment_response import ResponseWrapperIpnOrderPaymentResponse
from public_api_server_connector.models.response_wrapper_list_api_key_get import ResponseWrapperListApiKeyGet
from public_api_server_connector.models.response_wrapper_list_api_log_get import ResponseWrapperListApiLogGet
from public_api_server_connector.models.response_wrapper_list_category import ResponseWrapperListCategory
from public_api_server_connector.models.response_wrapper_list_content_block import ResponseWrapperListContentBlock
from public_api_server_connector.models.response_wrapper_list_course_module_simple import ResponseWrapperListCourseModuleSimple
from public_api_server_connector.models.response_wrapper_list_course_simple import ResponseWrapperListCourseSimple
from public_api_server_connector.models.response_wrapper_list_course_submodule import ResponseWrapperListCourseSubmodule
from public_api_server_connector.models.response_wrapper_list_file import ResponseWrapperListFile
from public_api_server_connector.models.response_wrapper_list_folder import ResponseWrapperListFolder
from public_api_server_connector.models.response_wrapper_list_module_lesson_simple import ResponseWrapperListModuleLessonSimple
from public_api_server_connector.models.response_wrapper_list_str import ResponseWrapperListStr
from public_api_server_connector.models.response_wrapper_module_lesson import ResponseWrapperModuleLesson
from public_api_server_connector.models.response_wrapper_module_lesson_simple import ResponseWrapperModuleLessonSimple
from public_api_server_connector.models.response_wrapper_token_info import ResponseWrapperTokenInfo
from public_api_server_connector.models.result import Result
from public_api_server_connector.models.token_info import TokenInfo
from public_api_server_connector.models.validation_error import ValidationError
